<?php

namespace Drupal\csv_field\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'csv_table' formatter.
 *
 * @FieldFormatter(
 *   id = "csv_table",
 *   label = @Translation("Render CSV as table"),
 *   field_types = {
 *     "csv_text",
 *   }
 * )
 */
class CsvTableFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    $settings = parent::defaultSettings();
    $settings['display_as_datatable'] = TRUE;
    $settings['client_side_rendering'] = TRUE;
    return $settings;
  }
  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);
    $form['display_as_datatable'] = [
      '#title' => $this->t('Display as DataTable'),
      '#type' => 'checkbox',
      '#default_value' => $this->getSetting('display_as_datatable'),
    ];
    $form['client_side_rendering'] = [
      '#title' => $this->t('Render CSV as table on the client'),
      '#type' => 'checkbox',
      '#default_value' => $this->getSetting('client_side_rendering'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();
    if ($this->getSetting('display_as_datatable')) {
      $summary[] = $this->t('Displayed as DataTable');
    }
    if ($this->getSetting('client_side_rendering')) {
      $summary[] = $this->t('Renders table on the client');
    }
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];

    foreach ($items as $delta => $item) {
      $lines = explode("\n", $item->value);
      $header = str_getcsv(array_shift($lines));

      $rows = [];
      foreach ($lines as $line) {
        $rows[] = str_getcsv($line);
      }

      if ($this->getSetting('client_side_rendering')) {
        $elements[$delta] = [
          '#theme' => 'csv_table',
          '#csv_data' => $item->value,
        ];

        if ($this->getSetting('display_as_datatable')) {
          $elements[$delta]['#attributes'] = ['class' => 'dataTable'];
        }
      }
      else {
        $elements[$delta] = [
          '#theme' => 'table',
          '#header' => $header,
          '#rows' => $rows,
        ];

        if ($this->getSetting('display_as_datatable')) {
          $elements[$delta] += [
            '#attributes' => ['class' => 'dataTable'],
            '#attached' => ['library' => ['csv_field/csv_datatables']],
          ];
        }
      }
    }

    return $elements;
  }

}
